#
# spec file for package srecord
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           srecord
Version:        1.65.0
%define short_version 1.65
Release:        bp160.1.7
%define so_ver  0
Summary:        Hex/bin format conversion package
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://srecord.sourceforge.net/
Source:         https://sourceforge.net/projects/srecord/files/srecord/%{short_version}/srecord-%{version}-Source.tar.gz
BuildRequires:  cmake >= 3.21
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
# groff-full for PDF output driver
BuildRequires:  groff-full
BuildRequires:  libgcrypt-devel

%description
The srecord package is a collection of powerful tools for manipulating EPROM
load files. It reads and writes numerous EPROM file formats, and can perform
many different manipulations.

%package     -n lib%{name}%{so_ver}
Summary:        Srecord libraries
Group:          System/Libraries

%description -n lib%{name}%{so_ver}
This package contains the shared libraries for programs that manipulate EPROM
load files.

%package        devel
Summary:        Srecord development files
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{so_ver} = %{version}

%description    devel
This package contains libraries and header files for compiling programs
that manipulate EPROM load files.

%package        doc
Summary:        Srecord PDF documentation
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
The srecord package is a collection of powerful tools for manipulating EPROM
load files. It reads and writes numerous EPROM file formats, and can perform
many different manipulations.

This package contains documentation in PDF format.

%prep
%setup -q -n %{name}-%{version}-Source
# Workaround git not working properly with tarball, fixed upstream
sed -ie '/GIT Hash Not Found/ d' etc/configure.cmake
# Fix library build
sed -ie '/add_library/ {
    s/STATIC// ;
    s/\${LIB_GCRYPT}//
    a target_link_libraries(lib_srecord \${LIB_GCRYPT})
    a set_target_properties(lib_srecord PROPERTIES OUTPUT_NAME srecord SOVERSION %{so_ver})
    } ' srecord/CMakeLists.txt
# Do not install system libraries
sed -ie '/install(RUNTIME_DEPENDENCY_SET/ a EXCLUDE_FROM_ALL' etc/packaging.cmake
# Prefer SVG icons, avoid dep on full graphviz
echo 'set(DOXYGEN_DOT_IMAGE_FORMAT svg)' >> etc/configure.cmake

%build
%cmake \
  -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
  %{nil}
%cmake_build

%install
%cmake_install
# Only keep the reference PDF, remove HTML versions of man pages
rm -rf %{buildroot}%{_docdir}/%{name}/htdocs

%check
%ctest

%post -n lib%{name}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{name}%{so_ver} -p /sbin/ldconfig

%files
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/srec_cat
%{_bindir}/srec_cmp
%{_bindir}/srec_info
%{_mandir}/man1/srec_*.1.gz
%{_mandir}/man5/srec_*.5.gz
%exclude %{_docdir}/%{name}/*.pdf

%files -n lib%{name}%{so_ver}
%{_libdir}/libsrecord.so.%{so_ver}*

%files devel
%{_libdir}/libsrecord.so
%{_includedir}/srecord
%{_mandir}/man3/srecord.3.gz
%{_mandir}/man3/srecord_license.3.gz

%files doc
%{_docdir}/%{name}/*.pdf

%changelog
* Sat Sep 30 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.65
  * HP64000 absolute file format contributed by fenugrec. Supports
    file input, tests and documentation.
  * Patch by dg1yfe as pulled from github via marcows. Updated man
    page for srec_ppb. Updated PPB output to match checksum range
    for output. Updated tests for PPB write and read including
    files containing holes. Added test for prolog stripping.
  * Verbose srec_info as suggested by Thomas. Display basic info
    on the proportion of input files which data/holes.
  * Bug fix from xiretza for COE generation falsly detecting holes
    in input.
  * Remove dependencies on boost moving to std shared_ptr and
    static_assert. Remove doc references to boost.
  * Fixed buffer overflow in four packed code output generator.
  * Marksu Heidelberg <markus.heidelberg@web.de> contributed a
    patch to fix a bug that he also found with the -generator
    which resulted in an endless loop.
  * Completely new build and config system to replace Aegis, Cook
    and autoconf with cmake & git. Integration with cpack to
    generate linux and windows packages. Integration with ctest to
    sustain the regression test suite.
- Use groff-full required for HTML and PDF generation
- Clean up spec file
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sat Aug  2 2014 dmitry_r@opensuse.org
- Update to version 1.64
  * Fixed some warnings in test 38
  * Fixed bugs regarding the formatting of some of the examples
    where lines were wrapping the wrong way.
  * Cleaned up a few recent compiler and doxygen warnings.
  * Added prefix and postfix strings to the C Array format which
    are applied at each end of the data array declaration. This
    allows the user to add various compiler directives such as
    location flags or non-standard load address specifiers.
  * when converting from AOMF Fixed Sourceforge bug 11 raised by
    patryks. In the analysis, it was discovered that a start address
    (of zero) was being generated when converting from AOMF. AOMF
    does not support the concept of an execution start address.
  * Fixed the length field description in extended tektronix
    documentation. The implementation was already correct.
  * Added a regression test for calculated address for CRC
- spec file cleanup
* Sun Apr 27 2014 wk@ire.pw.edu.pl - 1.63-9
- updated to 1.63
* Wed Aug 14 2013 W. Kazubski <wk@ire.pw.edu.pl> - 1.62-8
- updated to 1.62
* Sun May 12 2013 W. Kazubski <wk@ire.pw.edu.pl> - 1.61-7
- updated to 1.61
* Sun Sep  9 2012 W. Kazubski <wk@ire.pw.edu.pl> - 1.60-3
- initial specfile based on one provided by homepage
